@@ -2,7 +2,7 @@ package Business::CardInfo;
 use Moose;
 use Moose::Util::TypeConstraints;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 subtype 'CardNumber'
   => as 'Int'
@@ -50,7 +50,7 @@ sub _build_type {
     453978, 453979, 454313, 454432 .. 454435, 454742, 456725 .. 456745, 
     465830 .. 465879, 465901 .. 465950,475110 .. 475159, 475710 .. 475759, 
     476220 .. 476269, 476340 .. 476389, 484409 .. 484410, 484427, 
-    490960 .. 490979, 492181 .. 82, 498824, 499902
+    490960 .. 490979, 492181 .. 492182, 492186, 498824, 499902, 465942
   ]);
   return "Visa Electron" if $self->_search([
     417500, 400115, 400837 .. 400839, 412921 .. 412923, 417935, 419740, 
@@ -98,7 +98,7 @@ Business::CardInfo - Get/Validate data from credit & debit cards
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
